@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,20 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """FeatureDict: Main feature connector container.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import six
 import tensorflow.compat.v2 as tf
 
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.features import feature as feature_lib
 from tensorflow_datasets.core.features import top_level_feature
+from tensorflow_datasets.core.utils import type_utils
+
+Json = type_utils.Json
 
 
 class _DictGetCounter(object):
@@ -176,6 +174,19 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
         for feature_key, feature in self._feature_dict.items()
     }
 
+  @classmethod
+  def from_json_content(cls, value: Json) -> 'FeaturesDict':
+    return cls({
+        k: feature_lib.FeatureConnector.from_json(v)
+        for k, v in value.items()
+    })
+
+  def to_json_content(self) -> Json:
+    return {
+        feature_key: feature.to_json()
+        for feature_key, feature in self._feature_dict.items()
+    }
+
   def encode_example(self, example_dict):
     """See base class for details."""
     return {
