@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,8 +15,9 @@
 
 """Image feature."""
 
+import os
+
 import numpy as np
-import six
 import tensorflow.compat.v2 as tf
 
 from tensorflow_datasets.core import lazy_imports_lib
@@ -41,6 +42,8 @@ ACCEPTABLE_DTYPES = {
     'jpeg': [tf.uint8],
 }
 
+THUMBNAIL_SIZE = 128
+
 
 class Image(feature.FeatureConnector):
   """`FeatureConnector` for images.
@@ -142,9 +145,12 @@ class Image(feature.FeatureConnector):
     """Convert the given image into a dict convertible to tf example."""
     if isinstance(image_or_path_or_fobj, np.ndarray):
       encoded_image = self._encode_image(image_or_path_or_fobj)
-    elif isinstance(image_or_path_or_fobj, six.string_types):
+    elif isinstance(image_or_path_or_fobj, type_utils.PathLikeCls):
+      image_or_path_or_fobj = os.fspath(image_or_path_or_fobj)
       with tf.io.gfile.GFile(image_or_path_or_fobj, 'rb') as image_f:
         encoded_image = image_f.read()
+    elif isinstance(image_or_path_or_fobj, bytes):
+      encoded_image = image_or_path_or_fobj
     else:
       encoded_image = image_or_path_or_fobj.read()
     # If encoding is explicitly set, should verify that bytes match encoding.
@@ -199,7 +205,7 @@ def create_thumbnail(ex):
     mode = None
   img = PIL_Image.fromarray(ex, mode=mode)
   img = postprocess(img)
-  img.thumbnail((128, 128))  # Resize the image in-place
+  img.thumbnail((THUMBNAIL_SIZE, THUMBNAIL_SIZE))  # Resize the image in-place
   return img
 
 
