@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,9 +18,9 @@
 import os
 import subprocess
 import tempfile
+from typing import Any, List, Optional, Sequence
 
 import numpy as np
-import six
 import tensorflow.compat.v2 as tf
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.features import image_feature
@@ -28,6 +28,12 @@ from tensorflow_datasets.core.features import sequence_feature
 from tensorflow_datasets.core.utils import type_utils
 
 Json = type_utils.Json
+PilImage = Any  # Require lazy deps.
+
+# Framerate for the `tfds.as_dataframe` visualization
+# Could add a framerate kwargs in __init__ to allow datasets to customize
+# the output.
+_VISU_FRAMERATE = 10
 
 
 class Video(sequence_feature.Sequence):
@@ -45,6 +51,7 @@ class Video(sequence_feature.Sequence):
       [num_frames, height, width, channels], where channels must be 1 or 3
 
   Example:
+
     * In the DatasetInfo object:
 
     ```
@@ -69,7 +76,7 @@ class Video(sequence_feature.Sequence):
     }
     ```
 
-    or path to video:
+    or path to video (including `os.PathLike` objects):
 
     ```
     yield {
@@ -77,7 +84,7 @@ class Video(sequence_feature.Sequence):
     }
     ```
 
-    or file object:
+    or file object (or `bytes`):
 
     ```
     yield {
@@ -87,7 +94,12 @@ class Video(sequence_feature.Sequence):
 
   """
 
-  def __init__(self, shape, encoding_format='png', ffmpeg_extra_args=()):
+  def __init__(
+      self,
+      shape: Sequence[int],
+      encoding_format: str = 'png',
+      ffmpeg_extra_args: Sequence[str] = (),
+  ):
     """Initializes the connector.
 
     Args:
@@ -113,53 +125,28 @@ class Video(sequence_feature.Sequence):
         length=shape[0],
     )
 
-  @property
-  def _ffmpeg_path(self):
-    return 'ffmpeg'
-
   def _ffmpeg_decode(self, path_or_fobj):
-    if isinstance(path_or_fobj, six.string_types):
-      ffmpeg_args = [self._ffmpeg_path, '-i', path_or_fobj]
+    if isinstance(path_or_fobj, type_utils.PathLikeCls):
+      ffmpeg_args = ['-i', os.fspath(path_or_fobj)]
       ffmpeg_stdin = None
     else:
-      ffmpeg_args = [self._ffmpeg_path, '-i', 'pipe:0']
+      ffmpeg_args = ['-i', 'pipe:0']
       ffmpeg_stdin = path_or_fobj.read()
-
-    ffmpeg_dir = tempfile.mkdtemp()
-    output_pattern = os.path.join(ffmpeg_dir, '%010d.' + self._encoding_format)
     ffmpeg_args += self._extra_ffmpeg_args
-    ffmpeg_args.append(output_pattern)
-    try:
-      process = subprocess.Popen(ffmpeg_args,
-                                 stdin=subprocess.PIPE,
-                                 stdout=subprocess.PIPE,
-                                 stderr=subprocess.PIPE)
-      stdout_data, stderr_data = process.communicate(ffmpeg_stdin)
-      ffmpeg_ret_code = process.returncode
-      if ffmpeg_ret_code:
-        raise ValueError(
-            'ffmpeg returned error code {}, command={}\n'
-            'stdout={}\nstderr={}\n'.format(ffmpeg_ret_code,
-                                            ' '.join(ffmpeg_args),
-                                            stdout_data,
-                                            stderr_data))
-      frames = []
-      for image_name in sorted(tf.io.gfile.listdir(ffmpeg_dir)):
-        image_path = os.path.join(ffmpeg_dir, image_name)
-        with tf.io.gfile.GFile(image_path, 'rb') as frame_file:
-          frames.append(six.BytesIO(frame_file.read()))
-      return frames
-    except OSError as exception:
-      raise IOError(
-          'It seems that ffmpeg is not installed on the system. Please follow '
-          'the instrutions at https://ffmpeg.org/. '
-          'Original exception: {}'.format(exception))
-    finally:
-      tf.io.gfile.rmtree(ffmpeg_dir)
+
+    with tempfile.TemporaryDirectory() as ffmpeg_dir:
+      out_pattern = os.path.join(ffmpeg_dir, f'%010d.{self._encoding_format}')
+      ffmpeg_args.append(out_pattern)
+      _ffmpeg_run(ffmpeg_args, ffmpeg_stdin)
+      frames = [  # Load all encoded images
+          p.read_bytes() for p in sorted(utils.as_path(ffmpeg_dir).iterdir())
+      ]
+    return frames
 
   def encode_example(self, video_or_path_or_fobj):
     """Converts the given image into a dict convertible to tf example."""
-    if isinstance(video_or_path_or_fobj, six.string_types):
+    if isinstance(video_or_path_or_fobj, type_utils.PathLikeCls):
+      video_or_path_or_fobj = os.fspath(video_or_path_or_fobj)
       if not os.path.isfile(video_or_path_or_fobj):
         _, video_temp_path = tempfile.mkstemp()
         try:
@@ -178,7 +165,7 @@ class Video(sequence_feature.Sequence):
         encoded_video = self._ffmpeg_decode(video_temp_path)
     elif hasattr(video_or_path_or_fobj, 'read'):
       encoded_video = self._ffmpeg_decode(video_or_path_or_fobj)
-    else:
+    else:  # List of images, np.array,...
       encoded_video = video_or_path_or_fobj
     return super(Video, self).encode_example(encoded_video)
 
@@ -198,24 +185,100 @@ class Video(sequence_feature.Sequence):
 
   def repr_html(self, ex: np.ndarray) -> str:
     """Video are displayed as GIFs."""
-    # Use GIF as there is no easy way to generate a HTML5 compatible video
-    # without FFMPEG or other lib that the user is likelly to have on
-    # colab by default.
-    gif = [image_feature.create_thumbnail(frame) for frame in ex]
+    # Use GIF to generate a HTML5 compatible video if FFMPEG is not
+    # installed on the system.
+    images = [image_feature.create_thumbnail(frame) for frame in ex]
 
-    def write_buff(buff):
-      gif[0].save(
-          buff,
-          format='GIF',
-          save_all=True,
-          append_images=gif[1:],
-          # Could add a frame_rate kwargs in __init__ to customize this.
-          duration=41,  # 41ms / img ~= 24 img / sec
-          loop=0,
-      )
+    # Display the video HTML (either GIF of mp4 if ffmpeg is installed)
+    try:
+      _ffmpeg_run(['-version'])  # Check for ffmpeg installation.
+    except FileNotFoundError:
+      # print as `stderr` is displayed poorly on Colab
+      print('FFMPEG not detected. Falling back on GIF.')
+      return _get_repr_html_gif(images)
+    else:
+      return _get_repr_html_ffmpeg(images)
 
-    # Convert to base64
-    gif_str = utils.get_base64(write_buff)
 
-    # Display HTML
-    return f'<img src="data:image/gif;base64,{gif_str}"  alt="Gif" />'
+def _ffmpeg_run(
+    args: List[str],
+    stdin: Optional[bytes] = None,
+) -> None:
+  """Executes the ffmpeg function."""
+  ffmpeg_path = 'ffmpeg'
+  try:
+    cmd_args = [ffmpeg_path] + args
+    subprocess.run(
+        cmd_args,
+        check=True,
+        input=stdin,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+    )
+  except subprocess.CalledProcessError as e:
+    raise ValueError(
+        f'Command {e.cmd} returned error code {e.returncode}:\n'
+        f'stdout={e.stdout.decode("utf-8")}\n'
+        f'stderr={e.stderr.decode("utf-8")}\n'
+    )
+  except FileNotFoundError as e:
+    raise FileNotFoundError(
+        'It seems that ffmpeg is not installed on the system. Please follow '
+        'the instrutions at https://ffmpeg.org/. '
+        f'Original exception: {e}'
+    )
+
+
+def _get_repr_html_ffmpeg(images: List[PilImage]) -> str:
+  """Runs ffmpeg to get the mp4 encoded <video> str."""
+  # Find number of digits in len to give names.
+  num_digits = len(str(len(images))) + 1
+  with tempfile.TemporaryDirectory() as video_dir:
+    for i, img in enumerate(images):
+      f = os.path.join(video_dir, f'img{i:0{num_digits}d}.png')
+      img.save(f, format='png')
+
+    ffmpeg_args = [
+        '-framerate', str(_VISU_FRAMERATE),
+        '-i', os.path.join(video_dir, f'img%0{num_digits}d.png'),
+        # Using native h264 to encode video stream to H.264 codec
+        # Default encoding does not seems to be supported by chrome.
+        '-vcodec', 'h264',
+        # When outputting H.264, `-pix_fmt yuv420p` maximize compatibility
+        # with bad video players.
+        # Ref: https://trac.ffmpeg.org/wiki/Slideshow
+        '-pix_fmt', 'yuv420p',
+        # Native encoder cannot encode images of small scale
+        # or the the hardware encoder may be busy which raises
+        # Error: cannot create compression session
+        # so allow software encoding
+        # '-allow_sw', '1',
+    ]
+    video_path = utils.as_path(video_dir) / 'output.mp4'
+    ffmpeg_args.append(os.fspath(video_path))
+    _ffmpeg_run(ffmpeg_args)
+    video_str = utils.get_base64(video_path.read_bytes())
+  return (
+      f'<video height="{image_feature.THUMBNAIL_SIZE}" width="175" '
+      'controls loop autoplay muted playsinline>'
+      f'<source src="data:video/mp4;base64,{video_str}"  type="video/mp4" >'
+      '</video>'
+  )
+
+
+def _get_repr_html_gif(images: List[PilImage]) -> str:
+  """Get the <img/> str."""
+
+  def write_buff(buff):
+    images[0].save(
+        buff,
+        format='GIF',
+        save_all=True,
+        append_images=images[1:],
+        duration=1000 / _VISU_FRAMERATE,
+        loop=0,
+    )
+
+  # Convert to base64
+  gif_str = utils.get_base64(write_buff)
+  return f'<img src="data:image/png;base64,{gif_str}" alt="Gif" />'
