@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -101,4 +101,4 @@ class ImagenetR(tfds.core.GeneratorBasedBuilder):
             'label': class_synset,
             'file_name': image_path,
         }
-        yield image_path, features
+        yield f'{class_synset}_{image_filename}', features
