@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -49,9 +49,9 @@ _CITATION = """\
 }
 """
 
-DESCRIPTION = """COCO is a large-scale object detection, segmentation, and
-captioning dataset. This version contains images, bounding boxes "
-and labels for the {year} version.
+_DESCRIPTION = """COCO is a large-scale object detection, segmentation, and
+captioning dataset.
+
 Note:
  * Some images from the train and validation sets don't have annotations.
  * Coco 2014 and 2017 uses the same images, but different train/val/test splits
@@ -60,6 +60,10 @@ Note:
  * Panotptic annotations defines defines 200 classes but only uses 133.
 """
 
+_CONFIG_DESCRIPTION = """
+This version contains images, bounding boxes and labels for the {year} version.
+"""
+
 
 Split = collections.namedtuple(
     'Split', ['name', 'images', 'annotations', 'annotation_type'])
@@ -96,7 +100,7 @@ class Coco(tfds.core.GeneratorBasedBuilder):
   BUILDER_CONFIGS = [
       CocoConfig(
           name='2014',
-          description=DESCRIPTION.format(year=2014),
+          description=_CONFIG_DESCRIPTION.format(year=2014),
           splits=[
               Split(
                   name=tfds.Split.TRAIN,
@@ -127,7 +131,7 @@ class Coco(tfds.core.GeneratorBasedBuilder):
       ),
       CocoConfig(
           name='2017',
-          description=DESCRIPTION.format(year=2017),
+          description=_CONFIG_DESCRIPTION.format(year=2017),
           splits=[
               Split(
                   name=tfds.Split.TRAIN,
@@ -151,7 +155,7 @@ class Coco(tfds.core.GeneratorBasedBuilder):
       ),
       CocoConfig(
           name='2017_panoptic',
-          description=DESCRIPTION.format(year=2017),
+          description=_CONFIG_DESCRIPTION.format(year=2017),
           has_panoptic=True,
           splits=[
               Split(
@@ -213,7 +217,7 @@ class Coco(tfds.core.GeneratorBasedBuilder):
 
     return tfds.core.DatasetInfo(
         builder=self,
-        description=self.builder_config.description,
+        description=_DESCRIPTION,
         # More info could be added, like the segmentation (as png mask),
         # captions, person key-points. For caption encoding, it would probably
         # be better to have a separate class CocoCaption2014 to avoid poluting
