@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for wikipedia dataset module."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets import testing
 from tensorflow_datasets.text import wikipedia
 
@@ -27,7 +22,7 @@ from tensorflow_datasets.text import wikipedia
 class WikipediaTest(testing.DatasetBuilderTestCase):
   """Test Wikipedia Dataset generation on fake dataset."""
   DATASET_CLASS = wikipedia.Wikipedia
-  BUILDER_CONFIG_NAMES_TO_TEST = ["20200301.en"]
+  BUILDER_CONFIG_NAMES_TO_TEST = ["20201201.en"]
 
   # url_checksums are read from `dumpstatus.json`
   # Modify dumpstatus.json if `date` is not `20200301`
